Class: LibRubyParser::Nodes::Dsym

Inherits:
LibRubyParser::Node show all
Defined in:
lib/lib-ruby-parser/nodes.rb

Overview

Represents a symbol with interpolation (i.e. ‘:“#foo”`)

Instance Attribute Summary collapse

Instance Attribute Details

#begin_lLoc? (readonly)

Location of the symbol begin

“‘text :“#foo” ~~ “`

None if Dsym is a part of the interpolated symbol array:

“‘text %I “`

Returns:



1259
1260
1261
# File 'lib/lib-ruby-parser/nodes.rb', line 1259

def begin_l
  @begin_l
end

#end_lLoc? (readonly)

Location of the symbol begin

“‘text :“#foo”

~

“‘

None if Dsym is a part of the interpolated symbol array:

“‘text %I “`

Returns:



1274
1275
1276
# File 'lib/lib-ruby-parser/nodes.rb', line 1274

def end_l
  @end_l
end

#expression_lLoc (readonly)

Location of the full expression

“‘text :“#foo” ~~~~~~~~~ “`

Returns:



1283
1284
1285
# File 'lib/lib-ruby-parser/nodes.rb', line 1283

def expression_l
  @expression_l
end

#parts::Array<Node> (readonly)

A list of symbol parts (static literals and interpolated expressions)

Returns:



1244
1245
1246
# File 'lib/lib-ruby-parser/nodes.rb', line 1244

def parts
  @parts
end