Class: LibRubyParser::Nodes::EFlipFlop

Inherits:
LibRubyParser::Node show all
Defined in:
lib/lib-ruby-parser/nodes.rb

Overview

Represents exclusive flip-flop (i.e. in ‘if foo…bar; end`)

Instance Attribute Summary collapse

Instance Attribute Details

#expression_lLoc (readonly)

Location of the full expression

“‘text if foo…bar; end

~~~~~~~~~

“‘

Returns:



1313
1314
1315
# File 'lib/lib-ruby-parser/nodes.rb', line 1313

def expression_l
  @expression_l
end

#leftNode? (readonly)

Left part of the flip-flop. None if based on a range without begin (...bar)

Returns:



1291
1292
1293
# File 'lib/lib-ruby-parser/nodes.rb', line 1291

def left
  @left
end

#operator_lLoc (readonly)

Location of the ... operator

“‘text if foo…bar; end

~~~

“‘

Returns:



1304
1305
1306
# File 'lib/lib-ruby-parser/nodes.rb', line 1304

def operator_l
  @operator_l
end

#rightNode? (readonly)

Right part of the flip-flop. None if based on a range without end (foo...)

Returns:



1295
1296
1297
# File 'lib/lib-ruby-parser/nodes.rb', line 1295

def right
  @right
end