Method: LibRubyParser::Nodes::Ivasgn#operator_l
- Defined in:
- lib/lib-ruby-parser/nodes.rb
#operator_l ⇒ Loc? (readonly)
Location of the ‘=` operator.
“‘text “`
None if instance variable assignment is a part of the multi-assignment. In such case value is a part of the Masgn node.
2240 2241 2242 |
# File 'lib/lib-ruby-parser/nodes.rb', line 2240 def operator_l @operator_l end |